DATA_DIR = "/usr/share"
LIB_DIR = "/usr/lib"
VERSION = "2.26.2"
PACKAGE = "deskbar-applet"
